@@ -7,7 +7,8 @@ from ._astropy_init import *   # noqa
 # ----------------------------------------------------------------------------
 
 # top-level API as exposed to users
-from jdaviz.app import *
-from jdaviz.configs.specviz import SpecViz
-from jdaviz.configs.mosviz import MosViz
-from jdaviz.configs.cubeviz import CubeViz
+from jdaviz.app import *  # noqa
+from jdaviz.configs.specviz import SpecViz  # noqa
+from jdaviz.configs.specviz2d import Specviz2d  # noqa
+from jdaviz.configs.mosviz import MosViz  # noqa
+from jdaviz.configs.cubeviz import CubeViz  # noqa
