@@ -1,25 +1,22 @@
 import logging
 import os
+import pathlib
+import re
 import uuid
 from inspect import isclass
 
 import ipywidgets as w
-import numpy as np
-from astropy import units as u
-import pkg_resources
-import yaml
+
 from astropy.nddata import CCDData
-from spectral_cube import SpectralCube
 from echo import CallbackProperty, DictCallbackProperty, ListCallbackProperty
 from ipygoldenlayout import GoldenLayout
 from ipysplitpanes import SplitPanes
-from traitlets import Dict
+from traitlets import Dict, Bool
 from regions import RectanglePixelRegion, PixCoord
 from specutils import Spectrum1D
 
 from glue.config import data_translator
 from glue.core import BaseData, HubListener, Data, DataCollection
-from glue.core.autolinking import find_possible_links
 from glue.core.link_helpers import LinkSame
 from glue.core.message import (DataCollectionAddMessage,
                                DataCollectionDeleteMessage)
@@ -29,14 +26,14 @@ from glue_jupyter.app import JupyterApplication
 from glue_jupyter.state_traitlets_helpers import GlueState
 from ipyvuetify import VuetifyTemplate
 
+from .core.config import read_configuration, get_configuration
 from .core.events import (LoadDataMessage, NewViewerMessage, AddDataMessage,
-                          SnackbarMessage, RemoveDataMessage, ConfigurationLoadedMessage, AddDataToViewerMessage, RemoveDataFromViewerMessage)
+                          SnackbarMessage, RemoveDataMessage,
+                          AddDataToViewerMessage, RemoveDataFromViewerMessage)
 from .core.registries import (tool_registry, tray_registry, viewer_registry,
                               data_parser_registry)
 from .utils import load_template
 
-#from .configs.mosviz.plugins.viewers import MOSVizProfile2DView
-
 __all__ = ['Application']
 
 SplitPanes()
@@ -121,6 +118,8 @@ class Application(VuetifyTemplate, HubListener):
         "container.vue", __file__, traitlet=False)}).tag(
             sync=True, **w.widget_serialization)
 
+    loading = Bool(False).tag(sync=True)
+
     def __init__(self, configuration=None, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
@@ -132,13 +131,6 @@ class Application(VuetifyTemplate, HubListener):
         #  underlying glue infrastructure
         self._application_handler = JupyterApplication()
 
-        # We manually load plugins that are part of the "jdaviz_plugins"
-        #  group into the current namespace
-        plugins = {
-            entry_point.name: entry_point.load()
-            for entry_point
-            in pkg_resources.iter_entry_points(group='jdaviz_plugins')}
-
         # Create a dictionary for holding non-ipywidget viewer objects so we
         #  can reference their state easily since glue does not store viewers
         self._viewer_store = {}
@@ -183,6 +175,9 @@ class Application(VuetifyTemplate, HubListener):
         # Add callback that updates the layout when the data item array changes
         self.state.add_callback('stack_items', self.vue_relayout)
 
+        # Add a fitted_models dictionary that the helpers (or user) can access
+        self.fitted_models = {}
+
     @property
     def hub(self):
         """
@@ -246,13 +241,18 @@ class Application(VuetifyTemplate, HubListener):
         """
         new_len = len(self.data_collection)
         # Can't link if there's no world_component_ids
-        if self.data_collection[new_len-1].world_component_ids == []:
+        wc_new = self.data_collection[new_len-1].world_component_ids
+        if wc_new == []:
             return
+
+        # Link to the first dataset with compatible coordinates
         for i in range(0, new_len-1):
-            if self.data_collection[i].world_component_ids == []:
+            wc_old = self.data_collection[i].world_component_ids
+            if wc_old == []:
                 continue
-            self.data_collection.add_link(LinkSame(self.data_collection[i].world_component_ids[0],
-                    self.data_collection[new_len-1].world_component_ids[0]))
+            else:
+                self.data_collection.add_link(LinkSame(wc_old[0], wc_new[0]))
+                break
 
     def load_data(self, file_obj, parser_reference=None, **kwargs):
         """
@@ -266,27 +266,54 @@ class Application(VuetifyTemplate, HubListener):
         file_obj : str or file-like
             File object for the data to be loaded.
         """
-        old_data_len = len(self.data_collection)
-        parser = data_parser_registry.members.get(
-            self.state.settings['data'].get('parser') or parser_reference)
+        self.loading = True
+        try:
+            try:
+                # Properly form path and check if a valid file
+                file_obj = pathlib.Path(file_obj)
+                if not file_obj.exists():
+                    msg_text = "Error: File {} does not exist".format(file_obj)
+                    snackbar_message = SnackbarMessage(msg_text, sender=self,
+                                                       color='error')
+                    self.hub.broadcast(snackbar_message)
+                    raise FileNotFoundError("Could not locate file: {}".format(file_obj))
+                else:
+                    # Convert path to properly formatted string (Parsers do not accept path objs)
+                    file_obj = str(file_obj)
+            except TypeError:
+                # If it's not a str/path type, it might be a compatible class.
+                # Pass to parsers to see if they can accept it
+                pass
 
-        if parser is not None:
-            # If the parser returns something other than known, assume it's
-            #  a message we want to make the user aware of.
-            msg = parser(self, file_obj, **kwargs)
+            # attempt to get a data parser from the config settings
+            parser = None
+            data = self.state.settings.get('data', None)
+            if parser_reference:
+                parser = data_parser_registry.members.get(parser_reference)
+            elif data and isinstance(data, dict):
+                data_parser = data.get('parser', None)
+                if data_parser:
+                    parser = data_parser_registry.members.get(data_parser)
 
-            if msg is not None:
-                snackbar_message = SnackbarMessage(
-                    msg, color='error', sender=self)
-                self.hub.broadcast(snackbar_message)
-                return
-        else:
-            self._application_handler.load_data(file_obj)
+            if parser is not None:
+                # If the parser returns something other than known, assume it's
+                #  a message we want to make the user aware of.
+                msg = parser(self, file_obj, **kwargs)
 
-        # Send out a toast message
-        snackbar_message = SnackbarMessage("Data successfully loaded.",
-                                           sender=self)
-        self.hub.broadcast(snackbar_message)
+                if msg is not None:
+                    snackbar_message = SnackbarMessage(
+                        msg, color='error', sender=self)
+                    self.hub.broadcast(snackbar_message)
+                    return
+            else:
+                self._application_handler.load_data(file_obj)
+
+            # Send out a toast message
+            snackbar_message = SnackbarMessage("Data successfully loaded.",
+                                               sender=self)
+            self.hub.broadcast(snackbar_message)
+        finally:
+            self.loading = False
 
     def get_viewer(self, viewer_reference):
         """
@@ -544,7 +571,6 @@ class Application(VuetifyTemplate, HubListener):
             The name associated with this data. If none is given, a generic
             name is generated.
         """
-        old_data_len = len(self.data_collection)
 
         # Include the data in the data collection
         data_label = data_label or "New Data"
@@ -555,8 +581,39 @@ class Application(VuetifyTemplate, HubListener):
             f"Data '{data_label}' successfully added.", sender=self)
         self.hub.broadcast(snackbar_message)
 
-    def add_data_to_viewer(self, viewer_reference, data_label,
-                           clear_other_data=False):
+    @staticmethod
+    def _build_data_label(path, ext=None):
+        """ Build a data label from a filename and data extension
+
+        Builds a data_label out of a filename and data extension.
+        If the input string path already ends with a data
+        extension, the label is returned directly.  Otherwise a valid
+        extension must be specified to append to the file stem.
+
+        Parameters
+        ----------
+            path : str
+                The data filename to use as a
+            ext : str
+                The data extension to access from the file.
+        Returns
+        -------
+        A string data label used by Glue
+
+        """
+
+        # if path is not a file or already ends in [ ] extension, assume it is a data-label
+        if not os.path.isfile(path) or re.search(r'(.+)(\[(.*?)\])$', path):
+            return path
+        else:
+            assert ext, 'A data extension must be specified'
+            p = pathlib.Path(path)
+            stem = p.stem.split(os.extsep)[0]
+            label = f'{stem}[{ext}]'
+            return label
+
+    def add_data_to_viewer(self, viewer_reference, data_path,
+                           clear_other_data=False, ext=None):
         """
         Plots a data set from the data collection in the specific viewer.
 
@@ -565,13 +622,17 @@ class Application(VuetifyTemplate, HubListener):
         viewer_reference : str
             The reference to the viewer defined with the ``reference`` key
             in the yaml configuration file.
-        data_label : str
-            The Glue data label found in the ``DataCollection``.
+        data_path : str
+            Either the data filename or the Glue data label found in the ``DataCollection``.
         clear_other_data : bool
             Removes all other currently plotted data and only shows the newly
             defined data set.
+        ext: str
+            The data extension to access from a file.  If data_path is a filename, ext
+            is required.
         """
         viewer_item = self._viewer_item_by_reference(viewer_reference)
+        data_label = self._build_data_label(data_path, ext=ext)
         data_id = self._data_id_from_label(data_label)
 
         data_ids = viewer_item['selected_data_items'] \
@@ -583,10 +644,10 @@ class Application(VuetifyTemplate, HubListener):
         else:
             raise ValueError(
                 f"No data item found with label '{data_label}'. Label must be one "
-                f"of:\n\t" + f"\n\t".join([
+                "of:\n\t" + "\n\t".join([
                     data_item['name'] for data_item in self.state.data_items]))
 
-    def _set_plot_axes_labels(self,viewer_id):
+    def _set_plot_axes_labels(self, viewer_id):
         """
         Sets the plot axes labels to be the units of the data to be loaded.
 
@@ -599,7 +660,7 @@ class Application(VuetifyTemplate, HubListener):
 
         viewer.set_plot_axes()
 
-    def remove_data_from_viewer(self, viewer_reference, data_label):
+    def remove_data_from_viewer(self, viewer_reference, data_path, ext=None):
         """
         Removes a data set from the specified viewer.
 
@@ -608,10 +669,14 @@ class Application(VuetifyTemplate, HubListener):
         viewer_reference : str
             The reference to the viewer defined with the ``reference`` key
             in the yaml configuration file.
-        data_label : str
-            The Glue data label found in the ``DataCollection``.
+        data_path : str
+            Either the data filename or the Glue data label found in the ``DataCollection``.
+        ext: str
+            The data extension to access from a file.  If data_path is a filename, ext
+            is required.
         """
         viewer_item = self._viewer_item_by_reference(viewer_reference)
+        data_label = self._build_data_label(data_path, ext=ext)
         data_id = self._data_id_from_label(data_label)
 
         selected_items = viewer_item['selected_data_items']
@@ -804,7 +869,14 @@ class Application(VuetifyTemplate, HubListener):
         event : dict
             Traitlet event provided the 'old' and 'new' values.
         """
-        viewer_id, selected_items = event['id'], event['selected_items']
+        viewer_id, item_id, checked = event['id'], event['item_id'], event['checked']
+        viewer_item = self._viewer_item_by_id(viewer_id)
+
+        if checked:
+            selected_items = [*viewer_item['selected_data_items'], item_id]
+        else:
+            selected_items = list(filter(
+                lambda id: id != item_id, viewer_item['selected_data_items']))
 
         self._update_selected_data_items(viewer_id, selected_items)
 
@@ -1025,10 +1097,13 @@ class Application(VuetifyTemplate, HubListener):
 
         return viewer
 
-    def load_configuration(self, path=None):
+    def load_configuration(self, path=None, config=None):
         """
-        Parses the provided configuration yaml file and populates the
-        appropriate state values with the results.
+        Parses the provided input into a configuration
+        dictionary and populates the appropriate state values
+        with the results.  Provided input can either be a
+        configuration YAML file or a pre-made configuration
+        dictionary.
 
         Parameters
         ----------
@@ -1037,23 +1112,26 @@ class Application(VuetifyTemplate, HubListener):
             is ``None``, it loads the default configuration. Optionally, this
             can be provided as name reference. **NOTE** This optional way to
             define the configuration will be removed in future versions.
+        config : dict, optional
+            A dictionary of configuration settings to be loaded.  The dictionary
+            contents should be the same as a YAML config file specification.
         """
-        # Parse the default configuration file
-        default_path = os.path.join(os.path.dirname(__file__), "configs")
+        # reset the application state
+        self._reset_state()
 
-        if path is None or path == 'default':
-            path = os.path.join(default_path, "default", "default.yaml")
-        elif path == 'cubeviz':
-            path = os.path.join(default_path, "cubeviz", "cubeviz.yaml")
-        elif path == 'specviz':
-            path = os.path.join(default_path, "specviz", "specviz.yaml")
-        elif path == 'mosviz':
-            path = os.path.join(default_path, "mosviz", "mosviz.yaml")
-        elif not os.path.isfile(path):
-            raise ValueError("Configuration must be path to a .yaml file.")
+        # load the configuration from the yaml file or configuration object
+        assert not (path and config), 'Cannot specify both a path and a config object!'
+        if config:
+            assert isinstance(config, dict), 'configuration object must be a dictionary'
+        else:
+            # check if the input path is actually a dict object
+            if isinstance(path, dict):
+                config = path
+            else:
+                config = read_configuration(path=path)
 
-        with open(path, 'r') as f:
-            config = yaml.safe_load(f)
+        # store the loaded config object
+        self._loaded_configuration = config
 
         self.state.settings.update(config.get('settings'))
 
@@ -1111,6 +1189,33 @@ class Application(VuetifyTemplate, HubListener):
                 'widget': "IPY_MODEL_" + tray_item_instance.model_id
             })
 
-        config_loaded_message = ConfigurationLoadedMessage(
-            config['settings'].get('configuration', 'default'), sender=self)
-        self.hub.broadcast(config_loaded_message)
+    def _reset_state(self):
+        """ Resets the application state """
+        self.state = ApplicationState()
+        self.state.add_callback('stack_items', self.vue_relayout)
+
+    def get_configuration(self, path=None, section=None):
+        """ Returns a copy of the application configuration
+
+        Returns a copy of the configuration specification.  If path
+        is not specified, returns the currently loaded configuration.
+
+        Parameters
+        ----------
+        path : str, optional
+            path to the configuration file to be retrieved.
+        section : str, optional
+            A section of the configuration to retrieve
+
+        Returns
+        -------
+        A configuration specification dictionary
+
+        """
+
+        config = None
+        if not path:
+            config = self._loaded_configuration
+
+        cfg = get_configuration(path=path, section=section, config=config)
+        return cfg
