@@ -7,7 +7,7 @@ from glue.core.message import (DataCollectionAddMessage,
 from specutils import Spectrum1D
 from specutils.manipulation import gaussian_smooth
 from spectral_cube import SpectralCube
-from traitlets import List, Unicode, Int, Any, Bool, observe
+from traitlets import List, Unicode, Any, Bool, observe
 
 from jdaviz.core.events import SnackbarMessage
 from jdaviz.core.registries import tray_registry
@@ -64,7 +64,7 @@ class GaussianSmooth(TemplateMixin):
             spec = self._selected_data.get_object(cls=Spectrum1D)
         except TypeError:
             snackbar_message = SnackbarMessage(
-                f"Unable to perform smoothing over selected data.",
+                "Unable to perform smoothing over selected data.",
                 color="error",
                 sender=self)
             self.hub.broadcast(snackbar_message)
@@ -75,7 +75,16 @@ class GaussianSmooth(TemplateMixin):
         # define a standard deviation for gaussian smoothing
         spec_smoothed = gaussian_smooth(spec, stddev=size)
 
-        label = f"Smoothed {self._selected_data.label}"
+        label = f"Smoothed {self._selected_data.label} stddev {size}"
+
+        if label in self.data_collection:
+            snackbar_message = SnackbarMessage(
+                "Data with selected stddev already exists, canceling operation.",
+                color="error",
+                sender=self)
+            self.hub.broadcast(snackbar_message)
+
+            return
 
         self.data_collection[label] = spec_smoothed
 
@@ -112,7 +121,16 @@ class GaussianSmooth(TemplateMixin):
                                mask=cube.mask, meta=cube.meta,
                                fill_value=cube.fill_value)
 
-        label = f"Smoothed {self._selected_data.label}"
+        label = f"Smoothed {self._selected_data.label} spatial stddev {size}"
+
+        if label in self.data_collection:
+            snackbar_message = SnackbarMessage(
+                "Data with selected stddev already exists, canceling operation.",
+                color="error",
+                sender=self)
+            self.hub.broadcast(snackbar_message)
+
+            return
 
         self.data_collection[label] = newcube
 
