@@ -20,12 +20,13 @@ def test_linking_after_spectral_smooth(spectral_cube_wcs):
     gs.vue_spectral_smooth()
 
     assert len(dc) == 2
-    assert dc[1].label == 'Smoothed test'
+    assert dc[1].label == 'Smoothed test stddev 3.2'
     assert len(dc.external_links) == 1
 
     assert dc.external_links[0].cids1[0] is dc[0].world_component_ids[0]
     assert dc.external_links[0].cids2[0] is dc[1].world_component_ids[0]
 
+
 def test_spatial_convolution(spectral_cube_wcs):
 
     app = Application()
@@ -38,5 +39,5 @@ def test_spatial_convolution(spectral_cube_wcs):
     gs.vue_spatial_convolution()
 
     assert len(dc) == 2
-    assert dc[1].label == "Smoothed test"
-    assert dc["Smoothed test"].get_object(cls=SpectralCube).shape == (3,4,5)
+    assert dc[1].label == "Smoothed test spatial stddev 3.0"
+    assert dc["Smoothed test spatial stddev 3.0"].get_object(cls=SpectralCube).shape == (3, 4, 5)
