@@ -1,7 +1,10 @@
+import astropy.units as u
+
 from jdaviz.core.events import AddLineListMessage
 
 __all__ = ['LineListMixin']
 
+
 class LineListMixin:
     """
     Line list-related methods and properties for use in the configuration
@@ -13,9 +16,16 @@ class LineListMixin:
         broadcasts a message so the line list plugin UI can display lines
         loaded via the notebook.
         """
+
+        # If the helper class has a global redshift (as in Specviz), use it
+        if not isinstance(line_table, str):
+            if hasattr(self, "_redshift") and "redshift" not in line_table.colnames:
+                line_table["redshift"] = u.Quantity(self._redshift)
+
         lt = self.app.get_viewer('spectrum-viewer').load_line_list(line_table,
-                                                              replace=replace,
-                                                              return_table=True)
+                                                                   replace=replace,
+                                                                   return_table=True)
+
         # Preset lists were returning None table despite loading correctly
         if lt is None:
             if replace:
