@@ -1,11 +1,8 @@
-import os
-import pickle
 import re
 import numpy as np
 
 import astropy.modeling.models as models
 import astropy.units as u
-import numpy as np
 from astropy.wcs import WCSSUB_SPECTRAL
 from glue.core.message import (SubsetCreateMessage,
                                SubsetDeleteMessage,
@@ -40,9 +37,8 @@ class ModelFitting(TemplateMixin):
     template = load_template("model_fitting.vue", __file__).tag(sync=True)
     dc_items = List([]).tag(sync=True)
 
-    save_enabled = Bool(False).tag(sync=True)
     model_label = Unicode().tag(sync=True)
-    model_save_path = Unicode().tag(sync=True)
+    cube_fit = Bool(False).tag(sync=True)
     temp_name = Unicode().tag(sync=True)
     temp_model = Unicode().tag(sync=True)
     model_equation = Unicode().tag(sync=True)
@@ -65,9 +61,10 @@ class ModelFitting(TemplateMixin):
         self.component_models = []
         self._initialized_models = {}
         self._display_order = False
-        self.model_save_path = os.getcwd()
         self.model_label = "Model"
         self._selected_data_label = None
+        if self.app.state.settings.get("configuration") == "cubeviz":
+            self.cube_fit = True
 
         self.hub.subscribe(self, AddDataMessage,
                            handler=self._on_viewer_data_changed)
@@ -117,7 +114,7 @@ class ModelFitting(TemplateMixin):
         self.dc_items = [layer_state.layer.label
                          for layer_state in viewer.state.layers]
 
-    def _param_units(self, param, order = 0):
+    def _param_units(self, param, order=0):
         """Helper function to handle units that depend on x and y"""
         y_params = ["amplitude", "amplitude_L", "intercept"]
 
@@ -331,15 +328,6 @@ class ModelFitting(TemplateMixin):
                                  if x["id"] != event]
         del(self._initialized_models[event])
 
-    def vue_save_model(self, event):
-        if self.model_save_path[-1] == "/":
-            connector = ""
-        else:
-            connector = "/"
-        full_path = self.model_save_path + connector + self.model_label + ".pkl"
-        with open(full_path, 'wb') as f:
-            pickle.dump(self._fitted_model, f)
-
     def vue_equation_changed(self, event):
         # Length is a dummy check to test the infrastructure
         if len(self.model_equation) > 20:
@@ -370,9 +358,7 @@ class ModelFitting(TemplateMixin):
         self._fitted_spectrum = fitted_spectrum
 
         self.vue_register_spectrum({"spectrum": fitted_spectrum})
-        if not hasattr(self.app, "_fitted_1d_models"):
-            self.app._fitted_1d_models = {}
-        self.app._fitted_1d_models[self.model_label] = fitted_model
+        self.app.fitted_models[self.model_label] = fitted_model
 
         # Update component model parameters with fitted values
         if type(self._fitted_model) == QuantityModel:
@@ -380,8 +366,6 @@ class ModelFitting(TemplateMixin):
         else:
             self._update_parameters_from_fit()
 
-        self.save_enabled = True
-
     def vue_fit_model_to_cube(self, *args, **kwargs):
 
         if self._warn_if_no_equation():
@@ -420,7 +404,7 @@ class ModelFitting(TemplateMixin):
 
         # Retrieve copy of the models with proper "fixed" dictionaries
         # TODO: figure out why this was causing the parallel fitting to fail
-        #models_to_fit = self._reinitialize_with_fixed()
+        # models_to_fit = self._reinitialize_with_fixed()
         models_to_fit = self._initialized_models.values()
 
         fitted_model, fitted_spectrum = fit_model_to_spectrum(
@@ -431,12 +415,14 @@ class ModelFitting(TemplateMixin):
 
         # Save fitted 3D model in a way that the cubeviz
         # helper can access it.
-        self.app._fitted_3d_model = fitted_model
+        for m in fitted_model:
+            temp_label = "{} ({}, {})".format(self.model_label, m["x"], m["y"])
+            self.app.fitted_models[temp_label] = m["model"]
 
         # Transpose the axis order back
         values = np.moveaxis(fitted_spectrum.flux.value, -1, 0)
 
-        count = max(map(lambda s: int(next(iter(re.findall("\d$", s)), 0)),
+        count = max(map(lambda s: int(next(iter(re.findall(r"\d$", s)), 0)),
                         self.data_collection.labels)) + 1
 
         label = f"{self.model_label} [Cube] {count}"
@@ -472,8 +458,8 @@ class ModelFitting(TemplateMixin):
             spectrum = event["spectrum"]
         else:
             model, spectrum = fit_model_to_spectrum(self._spectrum1d,
-                                                self._initialized_models.values(),
-                                                self.model_equation)
+                                                    self._initialized_models.values(),
+                                                    self.model_equation)
 
         self.n_models += 1
         label = self.model_label
@@ -482,6 +468,5 @@ class ModelFitting(TemplateMixin):
             # Remove the actual Glue data object from the data_collection
             self.data_collection.remove(self.data_collection[label])
         self.data_collection[label] = spectrum
-        self.save_enabled = True
 
-        #self.app.add_data_to_viewer('spectrum-viewer', label)
+        self.app.add_data_to_viewer('spectrum-viewer', label)
