@@ -1,4 +1,5 @@
 import numpy as np
+from pathlib import Path
 
 from jdaviz.core.helpers import ConfigHelper
 from jdaviz.core.events import SnackbarMessage
@@ -81,7 +82,7 @@ class MosViz(ConfigHelper):
             try:
                 val = world[new_idx+extend_by]
             except IndexError:
-                val=old_val
+                val = old_val
                 msg = "Warning: panning too far away from the data may desync \
                        the 1D and 2D spectrum viewers"
                 msg = SnackbarMessage(msg, color='warning', sender=self)
@@ -160,7 +161,7 @@ class MosViz(ConfigHelper):
             for each item in ``data_obj`` if  ``data_obj`` is a list.
         """
         super().load_data(data_obj, parser_reference="mosviz-spec1d-parser",
-                           data_labels=data_labels)
+                          data_labels=data_labels)
 
     def load_2d_spectra(self, data_obj, data_labels=None):
         """
@@ -178,7 +179,10 @@ class MosViz(ConfigHelper):
             for each item in ``data_obj`` if  ``data_obj`` is a list.
         """
         super().load_data(data_obj, parser_reference="mosviz-spec2d-parser",
-                           data_labels=data_labels)
+                          data_labels=data_labels)
+
+    def load_niriss_data(self, data_obj, data_labels=None):
+        super().load_data(data_obj, parser_reference="mosviz-niriss-parser")
 
     def load_images(self, data_obj, data_labels=None):
         """
@@ -197,7 +201,7 @@ class MosViz(ConfigHelper):
             for each item in ``data_obj`` if  ``data_obj`` is a list.
         """
         super().load_data(data_obj, parser_reference="mosviz-image-parser",
-                           data_labels=data_labels)
+                          data_labels=data_labels)
 
     def add_column(self, data, column_name=None):
         """
@@ -229,8 +233,52 @@ class MosViz(ConfigHelper):
 
         for cid in table_data.components:
             comp = table_data.get_component(cid)
-            unit = u.Unit(comp.units)
+            # Rename the first column to something more sensible
+            if cid.label == "Pixel Axis 0 [x]":
+                label = "Table Index"
+            else:
+                label = cid.label
 
-            data_dict[cid.label] = comp.data * unit
+            if comp.units is not None:
+                if comp.units == "":
+                    data_dict[label] = comp.data
+                else:
+                    unit = u.Unit(comp.units)
+                    data_dict[label] = comp.data * unit
+            else:
+                data_dict[label] = comp.data
 
         return QTable(data_dict)
+
+    def to_csv(self, filename="MOS_data.csv", selected=False, overwrite=False):
+        """
+        Creates a csv file with the contects of the MOS table viewer
+
+        Parameters
+        ----------
+        filename: str
+            Filename for the output CSV file.
+        selected: bool
+            If set to True, only the checked rows in the table will be output.
+        """
+
+        path = Path(filename)
+        if path.is_file():
+            if not overwrite:
+                raise FileExistsError(f"File {filename} exists, choose another"
+                                      " file name or set overwrite=True")
+
+        table_df = self.app.data_collection['MOS Table'].to_dataframe()
+
+        if filename[-4:] != ".csv":
+            filename += ".csv"
+
+        # Restrict to only checked rows if desired
+        if selected:
+            checked_rows = self.app.get_viewer("table-viewer").widget_table.checked
+            table_df = table_df.iloc[checked_rows]
+
+        # This column is an artifact of the table widget construction with no meaning
+        table_df = table_df.drop(labels="Pixel Axis 0 [x]", axis=1)
+
+        table_df.to_csv(filename, index_label="Table Index")
