@@ -37,7 +37,8 @@ class MOSVizProfileView(BqplotProfileView):
         elif data.spectral_axis.unit.is_equivalent(u.pixel):
             spectral_axis_unit_type = "pixel"
 
-        self.figure.axes[0].label = f"{spectral_axis_unit_type} [{data.spectral_axis.unit.to_string()}]"
+        label_0 = f"{spectral_axis_unit_type} [{data.spectral_axis.unit.to_string()}]"
+        self.figure.axes[0].label = label_0
         self.figure.axes[1].label = f"{flux_unit_type} [{data.flux.unit.to_string()}]"
 
         # Make it so y axis label is not covering tick numbers.
@@ -49,7 +50,7 @@ class MOSVizImageView(BqplotImageView):
     default_class = None
 
     def data(self, cls=None):
-        return [layer_state.layer #.get_object(cls=cls or self.default_class)
+        return [layer_state.layer  # .get_object(cls=cls or self.default_class)
                 for layer_state in self.state.layers
                 if hasattr(layer_state, 'layer') and
                 isinstance(layer_state.layer, BaseData)]
@@ -125,9 +126,10 @@ class MOSVizTableViewer(TableViewer):
             if component.label == '1D Spectra':
                 prev_data = self._selected_data.get('spectrum-viewer')
                 if prev_data != selected_data:
-                    remove_data_from_viewer_message = RemoveDataFromViewerMessage(
-                        'spectrum-viewer', prev_data, sender=self)
-                    self.session.hub.broadcast(remove_data_from_viewer_message)
+                    if prev_data:
+                        remove_data_from_viewer_message = RemoveDataFromViewerMessage(
+                            'spectrum-viewer', prev_data, sender=self)
+                        self.session.hub.broadcast(remove_data_from_viewer_message)
 
                     add_data_to_viewer_message = AddDataToViewerMessage(
                         'spectrum-viewer', selected_data, sender=self)
@@ -138,9 +140,10 @@ class MOSVizTableViewer(TableViewer):
             if component.label == '2D Spectra':
                 prev_data = self._selected_data.get('spectrum-2d-viewer')
                 if prev_data != selected_data:
-                    remove_data_from_viewer_message = RemoveDataFromViewerMessage(
-                        'spectrum-2d-viewer', prev_data, sender=self)
-                    self.session.hub.broadcast(remove_data_from_viewer_message)
+                    if prev_data:
+                        remove_data_from_viewer_message = RemoveDataFromViewerMessage(
+                            'spectrum-2d-viewer', prev_data, sender=self)
+                        self.session.hub.broadcast(remove_data_from_viewer_message)
 
                     add_data_to_viewer_message = AddDataToViewerMessage(
                         'spectrum-2d-viewer', selected_data, sender=self)
@@ -151,9 +154,10 @@ class MOSVizTableViewer(TableViewer):
             if component.label == 'Images':
                 prev_data = self._selected_data.get('image-viewer')
                 if prev_data != selected_data:
-                    remove_data_from_viewer_message = RemoveDataFromViewerMessage(
-                        'image-viewer', prev_data, sender=self)
-                    self.session.hub.broadcast(remove_data_from_viewer_message)
+                    if prev_data:
+                        remove_data_from_viewer_message = RemoveDataFromViewerMessage(
+                            'image-viewer', prev_data, sender=self)
+                        self.session.hub.broadcast(remove_data_from_viewer_message)
 
                     add_data_to_viewer_message = AddDataToViewerMessage(
                         'image-viewer', selected_data, sender=self)
