@@ -1,4 +1,5 @@
 import astropy.units as u
+import csv
 import numpy as np
 import pytest
 from astropy.nddata import CCDData
@@ -136,7 +137,7 @@ def test_load_spectrum1d(mosviz_app, spectrum1d):
     assert isinstance(list(data.values())[0], Spectrum1D)
     assert list(data.keys())[0] == label
 
-    with pytest.raises(TypeError) as e:
+    with pytest.raises(TypeError):
         mosviz_app.load_1d_spectra([1, 2, 3])
 
 
@@ -206,6 +207,7 @@ def test_load_image(mosviz_app, image):
     assert list(data.values())[0].shape == (55, 55)
     assert list(data.keys())[0] == f"{label} 0"
 
+
 def test_viewer_axis_link(mosviz_app, spectrum1d, spectrum2d):
     label1d = "Test 1D Spectrum"
     mosviz_app.load_1d_spectra(spectrum1d, data_labels=label1d)
@@ -224,3 +226,24 @@ def test_viewer_axis_link(mosviz_app, spectrum1d, spectrum2d):
 
     scale_1d.max = 7564
     assert scale_2d.max == 800.0
+
+
+def test_to_csv(mosviz_app, spectrum_collection):
+    labels = [f"Test Spectrum Collection {i}" for i in range(5)]
+    mosviz_app.load_1d_spectra(spectrum_collection, data_labels=labels)
+
+    mosviz_app.to_csv()
+
+    found_rows = 0
+    found_index_label = False
+
+    with open("MOS_data.csv", "r") as f:
+        freader = csv.reader(f)
+        for row in freader:
+            if row[0] == "Table Index":
+                found_index_label = True
+            else:
+                found_rows += 1
+
+    assert found_index_label
+    assert found_rows == 5
