@@ -70,11 +70,13 @@ class SpecvizProfileView(BqplotProfileView):
 
         return data
 
-
-    def load_line_list(self, line_table, replace=False, return_table=False):
+    def load_line_list(self, line_table, replace=False, return_table=False, show=True):
+        # If string, load the named preset list and don't show by default
+        # since there might be too many lines
         if type(line_table) == str:
             self.load_line_list(load_preset_linelist(line_table),
-                                replace=replace, return_table=return_table)
+                                replace=replace, return_table=return_table,
+                                show=False)
             return
         elif type(line_table) != table.QTable:
             raise TypeError("Line list must be an astropy QTable with\
@@ -87,9 +89,12 @@ class SpecvizProfileView(BqplotProfileView):
         # Use the redshift of the displayed spectrum if no redshifts are specified
         if "redshift" not in line_table.colnames:
             line_table["redshift"] = self.data()[0].spectral_axis.redshift
+        # Make sure the redshift column is a quantity
+        line_table["redshift"] = u.Quantity(line_table["redshift"])
 
-        # Set all of the lines to be shown on the plot by default on load
-        line_table["show"] = True
+        # Set whether to show all of the lines on the plot by default on load
+        # We convert bool to int to work around ipywidgets json serialization
+        line_table["show"] = int(show)
 
         # If there is already a loaded table, convert units to match. This
         # attempts to do some sane rounding after the unit conversion.
@@ -160,9 +165,14 @@ class SpecvizProfileView(BqplotProfileView):
                 self.spectral_lines["show"] = False
         else:
             temp_marks = []
-            # Toggle "show" value in main astropy table
+            # Toggle "show" value in main astropy table. The astropy table
+            # machinery only allows updating a single row at a time.
             if name_rest is not None:
-                self.spectral_lines.loc[name_rest]["show"] = False
+                if type(name_rest) == str:
+                    self.spectral_lines.loc[name_rest]["show"] = False
+                elif type(name_rest) == list:
+                    for nr in name_rest:
+                        self.spectral_lines.loc[nr]["show"] = False
             # Get rid of the marks we no longer want
             for x in fig.marks:
                 if type(x) == SpectralLine:
@@ -171,7 +181,6 @@ class SpecvizProfileView(BqplotProfileView):
                         if x.name == name:
                             continue
                     else:
-                        self.spectral_lines.loc[name_rest]["show"] = False
                         if type(name_rest) == str:
                             if x.table_index == name_rest:
                                 continue
@@ -187,7 +196,7 @@ class SpecvizProfileView(BqplotProfileView):
         # with the scale retrieval
         if self.toolbar.active_tool is not None:
             self.toolbar.active_tool = None
-        return {'x': fig.interaction.x_scale, 'y':fig.interaction.y_scale}
+        return {'x': fig.interaction.x_scale, 'y': fig.interaction.y_scale}
 
     def plot_spectral_line(self, line, scales=None, plot_units=None, **kwargs):
         if type(line) == str:
@@ -340,8 +349,8 @@ class SpecvizProfileView(BqplotProfileView):
         if 'mask' in _data.components and self.display_mask:
 
             # If a mask was already plotted, remove it.
-            if hasattr(self,'mask_trace_pointer') and \
-                    self.mask_trace_pointer is not None:
+            if (hasattr(self, 'mask_trace_pointer') and
+                    self.mask_trace_pointer is not None):
                 marks = self.figure.marks[:]
                 self._clean_mask(marks)
                 self.figure.marks = marks
@@ -358,15 +367,15 @@ class SpecvizProfileView(BqplotProfileView):
 
             # there is no 'X' marker option in bqplot
             self.mask_line_mark = Scatter(scales=self.scales,
-                                marker='cross',
-                                x=x,
-                                y=y,
-                                stroke_width=0.5,
-                                # colors=['red'],
-                                colors=[self._color],
-                                default_size=25,
-                                default_opacities=[self._alpha],
-                                )
+                                          marker='cross',
+                                          x=x,
+                                          y=y,
+                                          stroke_width=0.5,
+                                          # colors=['red'],
+                                          colors=[self._color],
+                                          default_size=25,
+                                          default_opacities=[self._alpha],
+                                          )
             self.figure.marks = list(self.figure.marks) + [self.mask_line_mark]
 
             # We added an extra trace. Get pointer to it.
@@ -381,8 +390,8 @@ class SpecvizProfileView(BqplotProfileView):
             error = np.array(_data['uncertainty'].data)
 
             # If uncertainties were already plotted, remove them.
-            if hasattr(self,'error_trace_pointer') and \
-                    self.error_trace_pointer is not None:
+            if (hasattr(self, 'error_trace_pointer') and
+                    self.error_trace_pointer is not None):
                 marks = self.figure.marks[:]
                 self._clean_error(marks)
                 self.figure.marks = marks
@@ -397,16 +406,16 @@ class SpecvizProfileView(BqplotProfileView):
             # A Lines bqplot instance with two lines and shaded area
             # in between.
             self.error_line_mark = Lines(scales=self.scales,
-                              x=[x],
-                              y=[y],
-                              stroke_width=1,
-                              colors=[self._color, self._color],
-                              fill_colors=[self._color, self._color],
-                              opacities=[0.0, 0.0],
-                              fill_opacities=[self._alpha_shade, self._alpha_shade],
-                              fill='between',
-                              close_path=False
-                              )
+                                         x=[x],
+                                         y=[y],
+                                         stroke_width=1,
+                                         colors=[self._color, self._color],
+                                         fill_colors=[self._color, self._color],
+                                         opacities=[0.0, 0.0],
+                                         fill_opacities=[self._alpha_shade, self._alpha_shade],
+                                         fill='between',
+                                         close_path=False
+                                         )
             self.figure.marks = list(self.figure.marks) + [self.error_line_mark]
 
             # We added an extra trace. Get pointer to it.
@@ -427,7 +436,8 @@ class SpecvizProfileView(BqplotProfileView):
         elif data.spectral_axis.unit.is_equivalent(u.pixel):
             spectral_axis_unit_type = "pixel"
 
-        self.figure.axes[0].label = f"{spectral_axis_unit_type} [{data.spectral_axis.unit.to_string()}]"
+        label_0 = f"{spectral_axis_unit_type} [{data.spectral_axis.unit.to_string()}]"
+        self.figure.axes[0].label = label_0
         self.figure.axes[1].label = f"{flux_unit_type} [{data.flux.unit.to_string()}]"
 
         # Make it so y axis label is not covering tick numbers.
